@@ -16,6 +16,7 @@ import click
 import glean_parser
 
 
+from . import coverage as mod_coverage
 from . import lint
 from . import translate as mod_translate
 from . import validate_ping
@@ -140,6 +141,54 @@ def glinter(input, allow_reserved, allow_missing_files):
     )
 
 
+@click.command()
+@click.option(
+    "-c",
+    "--coverage_file",
+    type=click.Path(exists=True, dir_okay=False, file_okay=True, readable=True),
+    required=True,
+    multiple=True,
+)
+@click.argument(
+    "metrics_files",
+    type=click.Path(exists=True, dir_okay=False, file_okay=True, readable=True),
+    nargs=-1,
+)
+@click.option(
+    "-o",
+    "--output",
+    type=click.Path(exists=False, dir_okay=False, file_okay=True, writable=True),
+    required=True,
+)
+@click.option(
+    "--format", "-f", type=click.Choice(mod_coverage.OUTPUTTERS.keys()), required=True
+)
+@click.option(
+    "--allow-reserved",
+    is_flag=True,
+    help=(
+        "If provided, allow the use of reserved fields. "
+        "Should only be set when building the Glean library itself."
+    ),
+)
+def coverage(coverage_file, metrics_files, format, output, allow_reserved):
+    """
+    Produce a coverage analysis file given raw coverage output and a set of
+    metrics.yaml files.
+    """
+    sys.exit(
+        mod_coverage.coverage(
+            [Path(x) for x in coverage_file],
+            [Path(x) for x in metrics_files],
+            format,
+            Path(output),
+            {
+                "allow_reserved": allow_reserved,
+            },
+        )
+    )
+
+
 @click.group()
 @click.version_option(glean_parser.__version__, prog_name="glean_parser")
 def main(args=None):
@@ -150,6 +199,7 @@ def main(args=None):
 main.add_command(translate)
 main.add_command(check)
 main.add_command(glinter)
+main.add_command(coverage)
 
 
 def main_wrapper(args=None):
