@@ -96,7 +96,7 @@ def test_metric_type_name():
         type="event",
         category="category",
         name="metric",
-        bugs=[42],
+        bugs=["http://bugzilla.mozilla.com/12345"],
         notification_emails=["nobody@example.com"],
         description="description...",
         expires="never",
@@ -109,7 +109,7 @@ def test_metric_type_name():
         type="event",
         category="category",
         name="metric",
-        bugs=[42],
+        bugs=["http://bugzilla.mozilla.com/12345"],
         notification_emails=["nobody@example.com"],
         description="description...",
         expires="never",
@@ -121,7 +121,7 @@ def test_metric_type_name():
         type="boolean",
         category="category",
         name="metric",
-        bugs=[42],
+        bugs=["http://bugzilla.mozilla.com/12345"],
         notification_emails=["nobody@example.com"],
         description="description...",
         expires="never",
@@ -132,7 +132,7 @@ def test_metric_type_name():
         name="custom",
         description="description...",
         include_client_id=True,
-        bugs=[42],
+        bugs=["http://bugzilla.mozilla.com/12345"],
         notification_emails=["nobody@nowhere.com"],
     )
     assert csharp.type_name(ping) == "PingType<NoReasonCodes>"
@@ -141,7 +141,7 @@ def test_metric_type_name():
         name="custom",
         description="description...",
         include_client_id=True,
-        bugs=[42],
+        bugs=["http://bugzilla.mozilla.com/12345"],
         notification_emails=["nobody@nowhere.com"],
         reasons={"foo": "foolicious", "bar": "barlicious"},
     )
